@@ -1,9 +1,11 @@
 package Sah::Schema::unix::signal;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-29'; # DATE
+our $DATE = '2022-07-24'; # DATE
 our $DIST = 'Sah-Schemas-Unix'; # DIST
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 our $schema = ['str' => {
     'summary' => 'Unix signal name (e.g. TERM or KILL) or number (9 or 15)',
@@ -17,7 +19,6 @@ our $schema = ['str' => {
         # other tests
         {data=>'', valid=>0},
     ],
-_
 }];
 
 1;
@@ -35,72 +36,11 @@ Sah::Schema::unix::signal - Unix signal name (e.g. TERM or KILL) or number (9 or
 
 =head1 VERSION
 
-This document describes version 0.018 of Sah::Schema::unix::signal (from Perl distribution Sah-Schemas-Unix), released on 2021-07-29.
+This document describes version 0.019 of Sah::Schema::unix::signal (from Perl distribution Sah-Schemas-Unix), released on 2022-07-24.
 
 =head1 SYNOPSIS
 
-To check data against this schema (requires L<Data::Sah>):
-
- use Data::Sah qw(gen_validator);
- my $validator = gen_validator("unix::signal*");
- say $validator->($data) ? "valid" : "INVALID!";
-
- # Data::Sah can also create validator that returns nice error message string
- # and/or coerced value. Data::Sah can even create validator that targets other
- # language, like JavaScript. All from the same schema. See its documentation
- # for more details.
-
-To validate function parameters against this schema (requires L<Params::Sah>):
-
- use Params::Sah qw(gen_validator);
-
- sub myfunc {
-     my @args = @_;
-     state $validator = gen_validator("unix::signal*");
-     $validator->(\@args);
-     ...
- }
-
-To specify schema in L<Rinci> function metadata and use the metadata with
-L<Perinci::CmdLine> to create a CLI:
-
- # in lib/MyApp.pm
- package
-   MyApp;
- our %SPEC;
- $SPEC{myfunc} = {
-     v => 1.1,
-     summary => 'Routine to do blah ...',
-     args => {
-         arg1 => {
-             summary => 'The blah blah argument',
-             schema => ['unix::signal*'],
-         },
-         ...
-     },
- };
- sub myfunc {
-     my %args = @_;
-     ...
- }
- 1;
-
- # in myapp.pl
- package
-   main;
- use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
-
- # in command-line
- % ./myapp.pl --help
- myapp - Routine to do blah ...
- ...
-
- % ./myapp.pl --version
-
- % ./myapp.pl --arg1 ...
-
-Sample data:
+=head2 Sample data and validation results against this schema
 
  "HUP"  # valid
 
@@ -172,6 +112,105 @@ Sample data:
 
  ""  # INVALID
 
+=head2 Using with Data::Sah
+
+To check data against this schema (requires L<Data::Sah>):
+
+ use Data::Sah qw(gen_validator);
+ my $validator = gen_validator("unix::signal*");
+ say $validator->($data) ? "valid" : "INVALID!";
+
+The above schema returns a boolean result (true if data is valid, false if
+otherwise). To return an error message string instead (empty string if data is
+valid, a non-empty error message otherwise):
+
+ my $validator = gen_validator("unix::signal", {return_type=>'str_errmsg'});
+ my $errmsg = $validator->($data);
+ 
+ # a sample valid data
+ $data = 9;
+ my $errmsg = $validator->($data); # => ""
+ 
+ # a sample invalid data
+ $data = undef;
+ my $errmsg = $validator->($data); # => ""
+
+Often a schema has coercion rule or default value, so after validation the
+validated value is different. To return the validated (set-as-default, coerced,
+prefiltered) value:
+
+ my $validator = gen_validator("unix::signal", {return_type=>'str_errmsg+val'});
+ my $res = $validator->($data); # [$errmsg, $validated_val]
+ 
+ # a sample valid data
+ $data = 9;
+ my $res = $validator->($data); # => ["",9]
+ 
+ # a sample invalid data
+ $data = undef;
+ my $res = $validator->($data); # => ["",undef]
+
+Data::Sah can also create validator that returns a hash of detailed error
+message. Data::Sah can even create validator that targets other language, like
+JavaScript, from the same schema. Other things Data::Sah can do: show source
+code for validator, generate a validator code with debug comments and/or log
+statements, generate human text from schema. See its documentation for more
+details.
+
+=head2 Using with Params::Sah
+
+To validate function parameters against this schema (requires L<Params::Sah>):
+
+ use Params::Sah qw(gen_validator);
+
+ sub myfunc {
+     my @args = @_;
+     state $validator = gen_validator("unix::signal*");
+     $validator->(\@args);
+     ...
+ }
+
+=head2 Using with Perinci::CmdLine::Lite
+
+To specify schema in L<Rinci> function metadata and use the metadata with
+L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
+
+ # in lib/MyApp.pm
+ package
+   MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['unix::signal*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
+ 1;
+
+ # in myapp.pl
+ package
+   main;
+ use Perinci::CmdLine::Any;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
+
+ # in command-line
+ % ./myapp.pl --help
+ myapp - Routine to do blah ...
+ ...
+
+ % ./myapp.pl --version
+
+ % ./myapp.pl --arg1 ...
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Unix>.
@@ -180,6 +219,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Unix>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Unix>
@@ -188,15 +255,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
